@@ -1,6 +1,6 @@
-// Copyright 2008-present Contributors to the OpenImageIO project.
-// SPDX-License-Identifier: BSD-3-Clause
-// https://github.com/OpenImageIO/oiio
+// Copyright Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: Apache-2.0
+// https://github.com/AcademySoftwareFoundation/OpenImageIO
 
 // clang-format off
 
@@ -106,9 +106,8 @@ public:
         : m_chars(chars), m_len(len) { }
 
     /// Construct from char*, use strlen to determine length.
-    OIIO_CONSTEXPR17 basic_string_view(const CharT* chars) noexcept
-        : m_chars(chars), m_len(chars ? Traits::length(chars) : 0) { }
-    // N.B. char_traits::length() is constexpr starting with C++17.
+    constexpr basic_string_view(const CharT* chars) noexcept
+        : m_chars(chars), m_len(chars ? cestrlen(chars) : 0) { }
 
     /// Construct from std::string. Remember that a string_view doesn't have
     /// its own copy of the characters, so don't use the `string_view` after
@@ -431,6 +430,20 @@ private:
         return last;
     }
 
+    // Guaranteed constexpr length of a C string
+    static constexpr size_t cestrlen(const charT* chars) {
+#if OIIO_CPLUSPLUS_VERSION >= 17
+        return Traits::length(chars);
+#else
+        if (chars == nullptr)
+            return 0;
+        size_t len = 0;
+        while (chars[len] != 0)
+            len++;
+        return len;
+#endif
+    }
+
     class traits_eq {
     public:
         constexpr traits_eq (CharT ch) noexcept : ch(ch) {}
@@ -486,6 +499,18 @@ basic_string_view<char>::c_str() const {
 OIIO_NAMESPACE_END
 
 
+#if FMT_VERSION >= 100000
+FMT_BEGIN_NAMESPACE
+template <> struct formatter<OIIO::string_view> : formatter<string_view>
+{
+    auto format(OIIO::string_view c, format_context& ctx) const {
+        return formatter<string_view>::format(string_view(c), ctx);
+    }
+};
+FMT_END_NAMESPACE
+#endif
+
+
 
 // Declare std::size and std::ssize for our string_view.
 namespace std {
